@@ -292,8 +292,6 @@ class AxiStreamHandler():
             clock_cycles = []
             data = stacked
 
-        probs = []
-
         # FPS branch: fixed‑point → float by scaling
         if self.model_specs["data_type"].startswith("fps"):
             # data is int array of shape (N, n_output)
@@ -301,7 +299,9 @@ class AxiStreamHandler():
             #probs = data.astype(np.float64) / self.scale
             #preds = np.argmax(probs, axis=1).astype(int).tolist()
             hw_classifications = []
+            print(len(outputs))
             for outcome in outputs:
+                probs = []
                 for out in outcome:
                 
                     if self.model_specs["data_type"][:3] == "fps":
@@ -314,6 +314,7 @@ class AxiStreamHandler():
 
                 classification = np.argmax(probs)
                 hw_classifications.append(int(classification))
+            
             preds = hw_classifications
 
         # FLP branch: floating‑point with custom exponent/mantissa
@@ -340,6 +341,7 @@ class AxiStreamHandler():
             hw_classifications = []
             clock_cycles = []
             for outcome in outputs:
+                probs = []
                 for out in outcome:
                     if self.model_specs['register_size'] == 16:
                         for i in range(0, self.n_output):
@@ -433,6 +435,7 @@ class AxiStreamHandler():
                     else:
                         outputs.append(output_buffer)
 
+            print(outputs)
             if debug:
                 print("Time taken to predict a batch of size ", self.batch_size, " is ", np.mean(latencies), " ms")
                 print("Time taken to predict a single sample is ", np.mean(latencies)/self.batch_size, " ms")
